IF OBJECT_ID('[DockerRepositoryTags_Extended]') IS NOT NULL DROP VIEW [DockerRepositoryTags_Extended]
GO

CREATE VIEW [DockerRepositoryTags_Extended]
AS
	SELECT DRT.*,
		   DR.[Feed_Id],
		   DR.[Repository_Name],
		   DI.[Image_Digest],
		   DI.[Cached_Indicator],
		   DI.[Published_Date],
		   DI.[Canonical_Tag_Name],
		   DI.[Download_Count],
		   DIS.[DockerImage_Size],
		   VULN.[Vulnerabilities_Severity_Code],
		   VULN.[Vulnerabilities_Unassessed_Indicator],
		   [Vulnerabilities_Count] = COALESCE(VULN.[Vulnerabilities_Count],0),
		   [AssessedVulnerabilities_Count] = COALESCE(AVULN.[Vulnerabilities_Count],0),
		   F.[Active_Indicator],
		   F.[AllowUnassessedVulnerabilities_Indicator],
		   F.[Feed_Description],
		   F.[Feed_Name],
		   F.[FeedType_Name]
	  FROM [DockerRepositoryTags] DRT
	       INNER JOIN [DockerRepositories] DR
		           ON DR.[DockerRepository_Id] = DRT.[DockerRepository_Id]
		   INNER JOIN [DockerImages] DI
		           ON DI.[DockerImage_Id] = DRT.[DockerImage_Id]
		   LEFT JOIN (SELECT DIL.[DockerImage_Id], 
							 [Vulnerabilities_Severity_Code] = SUBSTRING('EWCN', MAX(CHARINDEX(A.[Severity_Code],'EWCN')), 1),
							 [Vulnerabilities_Unassessed_Indicator] = CASE WHEN COUNT(CASE WHEN A.[Severity_Code] IS NULL THEN 1 ELSE NULL END) = 0 THEN 'N' ELSE 'Y' END,
							 [Vulnerabilities_Count] = COUNT(*)
						FROM [Vulnerabilities] V
							 LEFT JOIN [AssessmentTypes] A
									ON A.[AssessmentType_Id] = V.[AssessmentType_Id]
								  AND (A.[Expiration_Days] IS NULL OR DATEADD(day, A.[Expiration_Days], V.[Assessment_Date]) > GETUTCDATE())
						   INNER JOIN [FeedVulnerabilitySources] FVS ON FVS.[VulnerabilitySource_Id] = V.[VulnerabilitySource_Id]
						   INNER JOIN [DockerBlobs] DB ON DB.[Blob_Digest] = V.[Blob_Digest]
						   INNER JOIN [DockerImageLayers] DIL ON DIL.[DockerBlob_Id] = DB.[DockerBlob_Id]
						   INNER JOIN [DockerImages] DI ON DI.[DockerImage_Id] = DIL.[DockerImage_Id]
						   INNER JOIN [DockerRepositories] IDR ON IDR.[DockerRepository_Id] = DI.[DockerRepository_Id]
						WHERE V.[Feed_Id] = IDR.[Feed_Id] OR FVS.[Feed_Id] = IDR.[Feed_Id]
						GROUP BY DIL.[DockerImage_Id]) VULN
					ON VULN.[DockerImage_Id] = DI.[DockerImage_Id]
			LEFT JOIN (SELECT DIL.[DockerImage_Id], 
							 [Vulnerabilities_Severity_Code] = SUBSTRING('EWCN', MAX(CHARINDEX(A.[Severity_Code],'EWCN')), 1),
							 [Vulnerabilities_Unassessed_Indicator] = CASE WHEN COUNT(CASE WHEN A.[Severity_Code] IS NULL THEN 1 ELSE NULL END) = 0 THEN 'N' ELSE 'Y' END,
							 [Vulnerabilities_Count] = COUNT(*)
						FROM [Vulnerabilities] V
							 LEFT JOIN [AssessmentTypes] A
									ON A.[AssessmentType_Id] = V.[AssessmentType_Id]
								  AND (A.[Expiration_Days] IS NULL OR DATEADD(day, A.[Expiration_Days], V.[Assessment_Date]) > GETUTCDATE())
						   INNER JOIN [FeedVulnerabilitySources] FVS ON FVS.[VulnerabilitySource_Id] = V.[VulnerabilitySource_Id]
						   INNER JOIN [DockerBlobs] DB ON DB.[Blob_Digest] = V.[Blob_Digest]
						   INNER JOIN [DockerImageLayers] DIL ON DIL.[DockerBlob_Id] = DB.[DockerBlob_Id]
						   INNER JOIN [DockerImages] DI ON DI.[DockerImage_Id] = DIL.[DockerImage_Id]
						   INNER JOIN [DockerRepositories] IDR ON IDR.[DockerRepository_Id] = DI.[DockerRepository_Id]
						WHERE (V.[Feed_Id] = IDR.[Feed_Id] OR FVS.[Feed_Id] = IDR.[Feed_Id]) AND v.AssessmentType_Id IS NOT NULL
						GROUP BY DIL.[DockerImage_Id]) AVULN
					ON AVULN.[DockerImage_Id] = DI.[DockerImage_Id]
			LEFT JOIN (SELECT DIL.[DockerImage_Id],
								SUM(DB.Blob_Size) as [DockerImage_Size]
							FROM [DockerImageLayers] DIL 
							INNER JOIN [DockerBlobs] DB
								ON DB.[DockerBlob_Id] = DIL.[DockerBlob_Id]
							GROUP BY DIL.[DockerImage_Id]
						) DIS
				ON DIS.[DockerImage_Id] = DRT.[DockerImage_Id]
		INNER JOIN [Feeds] F
			ON DR.[Feed_Id] = F.[Feed_Id]
GO
