EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'DockerImages_DeleteTag',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Deletes a Docker tag. Does not delete the referenced image.'
GO

IF OBJECT_ID('[DockerImages_DeleteTag]') IS NOT NULL DROP PROCEDURE [DockerImages_DeleteTag]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [DockerImages_DeleteTag]
(
    -- should be @DockerImage_Id and @Tag_Name Only
	@Feed_Id INT,
	@Repository_Name VARCHAR(255),
	@Tag_Name VARCHAR(128)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	-- HACK he should have different parameters and delete by ImageId
	DECLARE @DockerImage_Id INT = 
	    (SELECT [DockerImage_Id] FROM [DockerRepositoryTags_Extended]
		 WHERE [Feed_Id] = @Feed_Id
		   AND [Repository_Name] = @Repository_Name
		   AND [Tag_Name] = @Tag_Name)


	DELETE [DockerRepositoryTags]
	 WHERE [Tag_Name] = @Tag_Name 
	   AND [DockerImage_Id] = @DockerImage_Id

	UPDATE [DockerImages] SET [Canonical_Tag_Name] = NULL
	 WHERE [DockerImage_Id] = @DockerImage_Id
	   AND [Canonical_Tag_Name] = @Tag_Name

	EXEC [Events_RaiseEvent] 'PKGDEL', @Feed_Id, 'Package_Name', @Repository_Name, 'Package_Version', @Tag_Name

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [DockerImages_DeleteTag] TO [ProGetUser_Role]
GO
