EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'NuGetPackagesV2_SetListed',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Lists or unlists a NuGet package.'
GO

IF OBJECT_ID('[NuGetPackagesV2_SetListed]') IS NOT NULL DROP PROCEDURE [NuGetPackagesV2_SetListed]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO


CREATE PROCEDURE [NuGetPackagesV2_SetListed]
(
	@Feed_Id INT,
	@Package_Id VARCHAR(255),
	@Version_Text VARCHAR(255),
	@Listed_Indicator YNINDICATOR,
	@LatestVersion_Text VARCHAR(255),
	@LatestStableVersion_Text VARCHAR(255)
)
AS
BEGIN

SET NOCOUNT ON
SET QUOTED_IDENTIFIER ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @LatestVersion_Text IS NOT NULL BEGIN
		DECLARE @NuGetPackageV2_Id INT
		    SET @NuGetPackageV2_Id = (SELECT [NuGetPackageV2_Id]
		                                    FROM [NuGetPackagesV2]
		                                    WITH (UPDLOCK)
		                                   WHERE [Feed_Id] = @Feed_Id
		                                     AND [Package_Id] = @Package_Id)
		UPDATE [NuGetPackagesV2]
			SET [LatestVersion_Text] = @LatestVersion_Text,
				[LatestStableVersion_Text] = @LatestStableVersion_Text
			WHERE [NuGetPackageV2_Id] = @NuGetPackageV2_Id
	END

	UPDATE [NuGetPackageVersionsV2]
	   SET [Listed_Indicator] = @Listed_Indicator
	  FROM [NuGetPackageVersionsV2] V
	       INNER JOIN [NuGetPackagesV2] P
	               ON P.[NuGetPackageV2_Id] = V.[NuGetPackageV2_Id]
	 WHERE [Feed_Id] = @Feed_Id
	   AND [Package_Id] = @Package_Id 
	   AND [Version_Text] = @Version_Text

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [NuGetPackagesV2_SetListed] TO [ProGetUser_Role]